<?php

namespace Elementor;

class BEW_Blog extends BEW_Settings {
    
	public function get_name() {
		return 'bew-elements-blog';
	}
	
	public function get_title() {
		return __( 'Blog', 'bosa-elementor-for-woocommerce' );
	}
	
	public function get_icon() {
		return 'bew-widget eicon-posts-grid';
	}

	protected function get_available_post_types() {

		$post_type_args = [
			// Default is the value $public.
			'show_in_nav_menus' => true,
		];

		if(! empty($args['post_type'])) {
			$post_type_args['name'] = $args['post_type'];
		}

		$post_types = get_post_types($post_type_args , 'objects');

		$result = array(__('-- Select --', 'bosa-elementor-for-woocommerce'));

		foreach($post_types as $post_type => $object) {
			$result[ $post_type ] = $object->label;
		}

		return $result;
	}

    protected function register_controls() {

		$this->start_controls_section(
			'bew_elements_blog',
			[
				'label' => __( 'Content', 'bosa-elementor-for-woocommerce' ),
			]
		);

		$this->get_items_no();

		$this->add_responsive_control(
			'column_no',
			[
				'type' => \Elementor\Controls_Manager::SLIDER,
				'label' => esc_html__( 'Grid Columns', 'bosa-elementor-for-woocommerce' ),
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 6,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'desktop_default' => [
					'size' => 3,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 3,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' => 1,
					'unit' => 'px',
				],
			]
		);

		$this->add_control(
			'grid_style',
			[
				'label' 		=> __('Grid Style', 'bosa-elementor-for-woocommerce'),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> 'fit-rows',
				'options' 		=> [
					'fit-rows' 	=> __('Fit Rows', 'bosa-elementor-for-woocommerce'),
					'masonry' 	=> __('Masonry', 'bosa-elementor-for-woocommerce'),
				],
			]
		);

		$this->get_item_visibility( 'equal_heights', esc_html__( 'Equal Heights', 'bosa-elementor-for-woocommerce' ), esc_html__( 'Yes', 'bosa-elementor-for-woocommerce' ), esc_html__( 'No', 'bosa-elementor-for-woocommerce' ), $default="no" );

		$this->get_item_visibility( 'pagination', esc_html__( 'Pagination', 'bosa-elementor-for-woocommerce' ), esc_html__( 'Yes', 'bosa-elementor-for-woocommerce' ), esc_html__( 'No', 'bosa-elementor-for-woocommerce' ), $default="yes" );

		$this->add_control(
			'pagination_position',
			[
				'label' => esc_html__( 'Pagination Position', 'bosa-elementor-for-woocommerce' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bosa-elementor-for-woocommerce' ),
						'icon' => 'eicon-h-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bosa-elementor-for-woocommerce' ),
						'icon' => 'eicon-h-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bosa-elementor-for-woocommerce' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} ul.page-numbers' => 'text-align: {{VALUE}};',
				],
				'default' => 'center',
				'toggle' => true,
				'condition' => [
					'pagination' => 'yes',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'bew_elements_blog_query',
			[
				'label' => __( 'Query', 'bosa-elementor-for-woocommerce' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'post_type',
			[
				'label' 		=> __('Post Type', 'bosa-elementor-for-woocommerce'),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> '0',
				'options' 		=> $this->get_available_post_types(),
			]
		);

		$this->add_control(
			'order',
			[
				'label' 		=> __('Order', 'bosa-elementor-for-woocommerce'),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> '',
				'options' 		=> [
					'' 			=> __('Default', 'bosa-elementor-for-woocommerce'),
					'DESC' 		=> __('DESC', 'bosa-elementor-for-woocommerce'),
					'ASC' 		=> __('ASC', 'bosa-elementor-for-woocommerce'),
				],
			]
		);

		$this->add_control(
			'orderby',
			[
				'label' 		=> __('Order By', 'bosa-elementor-for-woocommerce'),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> '',
				'options' 		=> [
					'' 				=> __('Default', 'bosa-elementor-for-woocommerce'),
					'date' 			=> __('Date', 'bosa-elementor-for-woocommerce'),
					'title' 		=> __('Title', 'bosa-elementor-for-woocommerce'),
					'name' 			=> __('Name', 'bosa-elementor-for-woocommerce'),
					'modified' 		=> __('Modified', 'bosa-elementor-for-woocommerce'),
					'author' 		=> __('Author', 'bosa-elementor-for-woocommerce'),
					'rand' 			=> __('Random', 'bosa-elementor-for-woocommerce'),
					'ID' 			=> __('ID', 'bosa-elementor-for-woocommerce'),
					'comment_count' => __('Comment Count', 'bosa-elementor-for-woocommerce'),
					'menu_order' 	=> __('Menu Order', 'bosa-elementor-for-woocommerce'),
				],
			]
		);

		$this->add_control(
			'include_categories',
			[
				'label' 		=> __('Include Categories', 'bosa-elementor-for-woocommerce'),
				'description' 	=> __('Enter the categories slugs seperated by a "comma"', 'bosa-elementor-for-woocommerce'),
				'type' 			=> Controls_Manager::TEXT,
				'label_block' 	=> true,
				'condition'		=> [
					'post_type' => ['post', 'product'],
				]
			]
		);

		$this->add_control(
			'exclude_categories',
			[
				'label' 		=> __('Exclude Categories', 'bosa-elementor-for-woocommerce'),
				'description' 	=> __('Enter the categories slugs seperated by a "comma"', 'bosa-elementor-for-woocommerce'),
				'type' 			=> Controls_Manager::TEXT,
				'label_block' 	=> true,
				'condition'		=> [
					'post_type' => ['post', 'product'],
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
            'bew_elements_image_meta',
            [
                'label' => __('Elements', 'bosa-elementor-for-woocommerce')
            ]
       	);

		$this->add_control(
			'image_size',
			[
				'label' 		=> __('Image Size', 'bosa-elementor-for-woocommerce'),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> 'medium_large',
				'options' 		=> $this->get_img_sizes(),
			]
		);

		$this->add_control(
			'read_more_text',
			[
				'label' 		=> __('Learn More Text', 'bosa-elementor-for-woocommerce'),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> __('Learn More', 'bosa-elementor-for-woocommerce'),
				'label_block' 	=> true,
				'dynamic' 		=> [ 'active' => true ],
			]
		);

		$this->add_control(
			'title_visibility',
			[
				'label' 		=> __('Display Title', 'bosa-elementor-for-woocommerce'),
				'type' 			=> Controls_Manager::SWITCHER,
				'default' 		=> 'yes',
				'label_on' 		=> __('Show', 'bosa-elementor-for-woocommerce'),
				'label_off' 	=> __('Hide', 'bosa-elementor-for-woocommerce'),
			]
		);

		$this->add_control(
			'date_visibility',
			[
				'label' 		=> __('Display Date', 'bosa-elementor-for-woocommerce'),
				'type' 			=> Controls_Manager::SWITCHER,
				'default' 		=> 'yes',
				'label_on' 		=> __('Show', 'bosa-elementor-for-woocommerce'),
				'label_off' 	=> __('Hide', 'bosa-elementor-for-woocommerce'),
			]
		);

		$this->add_control(
			'comments_visibility',
			[
				'label' 		=> __('Display Comments', 'bosa-elementor-for-woocommerce'),
				'type' 			=> Controls_Manager::SWITCHER,
				'default' 		=> 'yes',
				'label_on' 		=> __('Show', 'bosa-elementor-for-woocommerce'),
				'label_off' 	=> __('Hide', 'bosa-elementor-for-woocommerce'),
			]
		);

		$this->add_control(
			'author_visibility',
			[
				'label' 		=> __('Display Author', 'bosa-elementor-for-woocommerce'),
				'type' 			=> Controls_Manager::SWITCHER,
				'default' 		=> 'yes',
				'label_on' 		=> __('Show', 'bosa-elementor-for-woocommerce'),
				'label_off' 	=> __('Hide', 'bosa-elementor-for-woocommerce'),
			]
		);

		$this->add_control(
			'cat_visibility',
			[
				'label' 		=> __('Display Categories', 'bosa-elementor-for-woocommerce'),
				'type' 			=> Controls_Manager::SWITCHER,
				'default' 		=> 'yes',
				'label_on' 		=> __('Show', 'bosa-elementor-for-woocommerce'),
				'label_off' 	=> __('Hide', 'bosa-elementor-for-woocommerce'),
			]
		);

		$this->add_control(
			'excerpt_visibility',
			[
				'label' 		=> __('Display Excerpt', 'bosa-elementor-for-woocommerce'),
				'type' 			=> Controls_Manager::SWITCHER,
				'default' 		=> 'yes',
				'label_on' 		=> __('Show', 'bosa-elementor-for-woocommerce'),
				'label_off' 	=> __('Hide', 'bosa-elementor-for-woocommerce'),
			]
		);

		$this->add_control(
			'excerpt_length',
			[
				'label' 		=> __('Excerpt Length', 'bosa-elementor-for-woocommerce'),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> '15',
				'label_block' 	=> true,
			]
		);

        $this->end_controls_section();

		$this->start_controls_section(
			'section_grid',
			[
				'label' 		=> __('Grid', 'bosa-elementor-for-woocommerce'),
				'tab' 			=> Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'grid_background_color',
			[
				'label' 		=> __('Background Color', 'bosa-elementor-for-woocommerce'),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .bew-elements-widgets .bew-elements-post-inner' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'grid_border_color',
			[
				'label' 		=> __('Border Color', 'bosa-elementor-for-woocommerce'),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .bew-elements-widgets .bew-elements-post-inner' => 'border-color: {{VALUE}};',
				],
			]
		);

        $this->end_controls_section();

        $this->start_controls_section(
			'bew_elements_blog_style',
			[
				'label' => __( 'Item', 'bosa-elementor-for-woocommerce' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->get_normal_color( 'bg_color', esc_html__( 'Background Color', 'bosa-elementor-for-woocommerce' ), '.bew-elements-container .bew-elements-post-inner', 'background-color' );

		$this->get_border_attr( 'blog_border', '.bew-elements-container .bew-elements-post-inner' );

		$this->get_border_radius( 'blog_border_radius', esc_html__( 'Border Radius', 'bosa-elementor-for-woocommerce' ), '.bew-elements-container .bew-elements-post-inner', 'border-radius' );

		$this->get_margin( 'blog_margin', '.bew-elements-container .bew-elements-post-inner' );

		$this->get_padding( 'blog_padding', '.bew-elements-container .bew-elements-post-inner' );

        $this->end_controls_section();

        $this->start_controls_section(
			'bew_elements_blog_img_style',
			[
				'label' => __( 'Image', 'bosa-elementor-for-woocommerce' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->get_border_attr( 'img_border', '.bew-elements-container .bew-elements-post .bew-featured-image img' );

		$this->get_border_radius( 'img_border_radius', esc_html__( 'Border Radius', 'bosa-elementor-for-woocommerce' ), '.bew-elements-container .bew-elements-post .bew-featured-image img', 'border-radius' );

		$this->get_margin( 'img_margin', '.bew-elements-container .bew-elements-post .bew-featured-image img' );

		$this->get_padding( 'img_padding', '.bew-elements-container .bew-elements-post .bew-featured-image img' );

		$this->end_controls_section();

		$this->start_controls_section(
			'bew_elements_title_style',
			[
				'label' => __( 'Title', 'bosa-elementor-for-woocommerce' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->get_normal_color('title_color', esc_html__( 'Color', 'bosa-elementor-for-woocommerce' ), '.bew-elements-post .bew-blog-title', 'color');

        $this->get_normal_color('hov_title_color', esc_html__( 'Hover Color', 'bosa-elementor-for-woocommerce' ), '.bew-elements-post .bew-blog-title a:hover', 'color');

		$this->get_title_typography('title_typography', '.bew-elements-post .bew-blog-title');

        $this->get_margin( 'title_margin', '.bew-elements-post .bew-blog-title' );

		$this->end_controls_section();

		$this->start_controls_section(
			'bew_elements_blog_categories',
			[
				'label' => __( 'Categories', 'bosa-elementor-for-woocommerce' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->get_normal_color('categories_color', esc_html__( 'Color', 'bosa-elementor-for-woocommerce' ), '.bew-blog-categories a', 'color');

		$this->get_normal_color('categories_hover_color', esc_html__( 'Color: Hover', 'bosa-elementor-for-woocommerce' ), '.bew-blog-categories a:hover', 'color');

		$this->end_controls_section();

        $this->start_controls_section(
			'bew_elements_excerpt_style',
			[
				'label' => __( 'Excerpt', 'bosa-elementor-for-woocommerce' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

        $this->get_normal_color('excerpt_color', esc_html__('Color', 'bosa-elementor-for-woocommerce'), '.bew-elements-post .bew-blog-excerpt', 'color');

        $this->get_title_typography('excerpt_typography', '.bew-elements-container .bew-elements-post .bew-blog-excerpt');

        $this->end_controls_section();

        $this->start_controls_section(
			'bew_elements_meta_style',
			[
				'label' => __( 'Meta', 'bosa-elementor-for-woocommerce' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->get_normal_color('meta_color', esc_html__('Color', 'bosa-elementor-for-woocommerce'), '.bew-post-meta', 'color');

		$this->get_normal_color('meta_hover_color', esc_html__('Color: Hover', 'bosa-elementor-for-woocommerce'), '.bew-post-meta > div:hover', 'color');

		$this->get_title_typography('meta_typography', '.bew-post-meta a');

		$this->add_control(
			'icon-size',
			[
				'label' => esc_html__( 'Icon Size', 'bosa-elementor-for-woocommerce' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 40,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 16,
				],
				'selectors' => [
					'{{WRAPPER}} .bew-post-meta i' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);


        $this->end_controls_section();

		$this->start_controls_section(
			'bew_elements_blog_button_style',
			[
				'label' => __( 'Button', 'bosa-elementor-for-woocommerce' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->get_title_typography('button_typography', '.read-more-blog');

		$this->start_controls_tabs(
			'button_tabs'
		);
		
		$this->start_controls_tab(
			'button_normal_tab',
			[
				'label' => esc_html__( 'Normal', 'bosa-elementor-for-woocommerce' ),
			]
		);

		$this->get_normal_color('btn_bg_color', esc_html__('Background Color', 'bosa-elementor-for-woocommerce'), '.read-more-blog', 'background-color');

		$this->get_normal_color('btn_color', esc_html__('Color', 'bosa-elementor-for-woocommerce'), '.read-more-blog', 'color');

		$this->get_normal_color('btn_border_color', esc_html__('Border Color', 'bosa-elementor-for-woocommerce'), '.read-more-blog', 'border-color');
		
		$this->end_controls_tab();

		$this->start_controls_tab(
			'button_hover_tab',
			[
				'label' => esc_html__( 'Hover', 'bosa-elementor-for-woocommerce' ),
			]
		);

		$this->get_normal_color('btn_hov_bg_color', esc_html__('Background Color', 'bosa-elementor-for-woocommerce'), '.read-more-blog:hover', 'background-color');

		$this->get_normal_color('btn_hov_color', esc_html__('Color', 'bosa-elementor-for-woocommerce'), '.read-more-blog:hover', 'color');

		$this->get_normal_color('btn_hov_border_color', esc_html__('Border Color', 'bosa-elementor-for-woocommerce'), '.read-more-blog:hover', 'border-color');
		
		$this->end_controls_tab();
		
		$this->end_controls_tabs();

		$this->get_margin('btn_margin', '.bew-blog-btn');

		$this->get_padding('btn_padding', '.read-more-blog');

		$this->end_controls_section();

	}

	protected function render() {
        $settings       		= $this->get_settings_for_display();
        $items_no           	= $settings['items_no'];
		$post_type 				= $settings['post_type'];
		$post_type 				= $post_type ? $post_type : 'post';
		$posts_per_page 		= $settings['items_no'];
		$order 					= $settings['order'];
		$orderby  				= $settings['orderby'];
	    $include_categories 	= $settings['include_categories'];
	    $exclude_categories		= $settings['exclude_categories'];
		$pagination  			= $settings['pagination'];
		$read_more 				= $settings['read_more_text'];
		$title_visibility   	= $settings['title_visibility'];
		$date_visibility 		= $settings['date_visibility'];
		$excerpt_visibility 	= $settings['excerpt_visibility'];
		$author_visibility		= $settings['author_visibility'];
		$comments_visibility 	= $settings['comments_visibility'];
		$cat_visibility 		= $settings['cat_visibility'];

		$include_categories = explode( ',', $include_categories );
		$exclude_categories = explode( ',', $exclude_categories );

		$categories_in = $categories_out = [];

		if( $post_type === 'post' ) {
			foreach( $include_categories as $include_category ) {
				$cat_data = get_category_by_slug( $include_category );
				if( is_object( $cat_data ) ) {
					array_push( $categories_in, $cat_data->term_id );
				}
			}

			foreach( $exclude_categories as $exclude_category ) {
				$cat_data = get_category_by_slug( $exclude_category );
				if( is_object( $cat_data ) ) {
					array_push( $categories_out, $cat_data->term_id );	
				}
			}
		}

		if( $post_type === 'product' ) {
			foreach( $include_categories as $include_category ) {
				$cat_data = get_term_by( 'slug', $include_category, 'product_cat' );
				if( is_object( $cat_data ) ) {
					array_push( $categories_in, $cat_data->term_id );
				}
			}

			foreach( $exclude_categories as $exclude_category ) {
				$cat_data = get_term_by( 'slug', $exclude_category, 'product_cat' );
				if( is_object( $cat_data ) ) {
					array_push( $categories_out, $cat_data->term_id );
				}
			}
		}
       
        // Paged
		global $paged;
		if(get_query_var('paged')) {
			$paged = get_query_var('paged');
		} else if(get_query_var('page')) {
			$paged = get_query_var('page');
		} else {
			$paged = 1;
		}

		if( $post_type === 'post' ) {
			$args = array(
				'post_type'          => $post_type,
				'posts_per_page'    => $posts_per_page,
				'cat'				=> $categories_in,
				'category__not_in'  => $categories_out,
			   );
		} else if( $post_type === 'product' ) {
			$args = array(
				'post_type' 		=> 'product',
				'posts_per_page'	=> $posts_per_page,
				'tax_query'			=> array(											
											'relation' => 'AND',
											array(
												'taxonomy' => 'product_cat',
												'terms' => $categories_in,
												'operator' => 'IN',
											),
											array(
												'taxonomy' => 'product_cat',
												'terms' => $categories_out,
												'operator' => 'NOT IN',
											),
											array(
												'taxonomy' => 'product_visibility',
												'field' => 'name',
												'terms' => 'exclude-from-catalog',
												'operator' => 'NOT IN',
											),
										),
											
									);
			
		} else {
			$args = array(
				'post_type' 		=> $post_type,
				'posts_per_page'	=> $posts_per_page,
				'order'             => $order,
				'orderby'           => $orderby,
			);
		}

		$args['paged'] 		= $paged;
		$args['order'] 		= $order;
		$args['orderby'] 	= $orderby;

		// Wrapper classes
		$wrapper_classes = array('bew-blog-grid');

		if('masonry' === $settings['grid_style']) {
			$wrapper_classes[] = 'bew-masonry';
		}else{
			if('yes' === $settings['equal_heights']) {
				$wrapper_classes[] = 'bew-match-height-grid';
			}
		}

		

		$wrapper_classes = implode(' ', $wrapper_classes);

		// Image size
		$img_size 		= $settings['image_size'];
		$img_size 		= $img_size ? $img_size : 'medium_large';

	?>

		<section class="bew-elements-widgets display-grid bew-elements-container <?php echo esc_attr($wrapper_classes); ?>" <?php echo $this->get_column_attr($settings); ?>>
            <?php
                $query = new \WP_Query( $args );
                if($query->have_posts()) {
                    while($query->have_posts()) {
                        $query->the_post();
                        $image_id 				= get_post_thumbnail_id();
                        $image_alt 				= get_post_meta($image_id, '_wp_attachment_image_alt', TRUE);
                        $get_author_id 			= get_the_author_meta( 'ID' );
                        $get_author_gravatar 	= get_avatar_url($get_author_id, array('size' => 450));
						if( $post_type === 'post' ) {
							$tax_name = 'category';
						} else if( $post_type === 'product' ) {
							$tax_name = 'product_cat';
						}
						$post_categories 		= get_the_terms(get_the_ID(), $tax_name);
            ?>

                <div class="bew-elements-post">
                    <article class="bew-elements-post-inner">
                    	<?php if(has_post_thumbnail()) { ?>
	                    	<div class="bew-featured-image">
	                    		<a href="<?php the_permalink(); ?>">
			                       <?php
										// Display post thumbnail
										the_post_thumbnail($img_size, array(
											'alt'		=> get_the_title(),
											'itemprop' 	=> 'image',
										));
								   ?>
								</a>
		                    </div>
	                    <?php } ?>
	                    <div class="bew-blog-content">
	                        <?php $content = apply_filters('the_content', get_the_content()); ?>
	                        <?php if( $cat_visibility === 'yes' ) : ?>
							<div class="bew-blog-categories">
								<?php foreach( $post_categories as $post_category ) { ?>
									<a href="<?php echo esc_url( get_term_link( $post_category->term_id ) ); ?>" class=""><?php echo esc_html( $post_category->name ); ?></a>
								<?php } ?>
							</div>
							<?php endif; ?>
							<?php if( $title_visibility === 'yes' ) : ?>
								<h3 class="bew-blog-title">
									<a href="<?php the_permalink(); ?>">
		                        		<?php esc_html(the_title()); ?>
									</a>
								</h3>
							<?php endif; ?>
	                        <div class="bew-post-meta">
								<?php if( $date_visibility === 'yes' ) : 
										$archive_year  = get_the_time('Y'); 
										$archive_month = get_the_time('m'); 
										$archive_day   = get_the_time('d');
										
									?>
									<div class="bew-post-on">
										<span class="icon_space"><i class="far fa-clock"></i></span>
										<a href="<?php echo get_day_link( $archive_year, $archive_month, $archive_day); ?>">
											<?php echo esc_html(get_the_date()); ?>
										</a>
									</div>
								<?php endif; ?>
								<?php if('yes' == $comments_visibility && comments_open() && ! post_password_required()) { ?>
									<div class="meta-comments"><span class="icon_space"><i class="far fa-comment"></i></span><?php comments_popup_link(esc_html__('0 Comments', 'bosa-elementor-for-woocommerce'), esc_html__('1 Comment',  'bosa-elementor-for-woocommerce'), esc_html__('% Comments', 'bosa-elementor-for-woocommerce'), 'comments-link'); ?></div>
								<?php } ?>
								<?php if( $author_visibility === 'yes' ) : ?>
									<div class="bew-byline">
										<span class="icon_space"><i class="far fa-user"></i></span>
										<a href="<?php echo esc_url(get_author_posts_url(get_the_author_meta('ID'))); ?>" title="<?php esc_attr_e('Visit Author Page', 'bosa-elementor-for-woocommerce'); ?>" class="entry-author-link" rel="author" >
											<?php echo esc_html(get_the_author()); ?>
										</a>
									</div>
								<?php endif; ?>
		                    </div>
							<?php if( $excerpt_visibility === 'yes' ) : ?>
	                        <div class="bew-blog-excerpt">
	                        	<?php echo wp_kses_post(wp_trim_words(get_the_content(), intval( $settings['excerpt_length'] ), '' ) ); ?>
	                        </div>
							<div class="bew-blog-btn">
								<a href="<?php the_permalink(); ?>" class="read-more-blog"><?php echo esc_html( $read_more ); ?></a>
							</div>
							<?php endif; ?>
	                    </div>
                    </article>
                </div>

            <?php } } \wp_reset_postdata(); ?>
      	</section>
	
	<?php

	// Display pagination if enabled
	if('yes' == $pagination) {
		$this->bew_pagination($query);
	} 

	}
	
}